@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import sys
 from typing import Any, Literal
 from datetime import timedelta
 
@@ -12,6 +13,12 @@ from temporalio.common import RetryPolicy
 from agents.agent_output import AgentOutputSchemaBase
 from agents.model_settings import ModelSettings
 
+# Use warnings.deprecated in Python 3.13+, typing_extensions.deprecated for older versions
+if sys.version_info >= (3, 13):
+    from warnings import deprecated
+else:
+    from typing_extensions import deprecated
+
 from agentex.lib.utils.logging import make_logger
 from agentex.lib.utils.temporal import in_temporal_workflow
 from agentex.lib.core.tracing.tracer import AsyncTracer
@@ -383,6 +390,10 @@ class OpenAIModule:
             previous_response_id=previous_response_id,
         )
 
+    @deprecated(
+        "Use the OpenAI Agents SDK integration with Temporal instead. "
+        "See examples in tutorials/10_async/10_temporal/ for migration guidance."
+    )
     async def run_agent_streamed_auto_send(
         self,
         task_id: str,
@@ -413,6 +424,10 @@ class OpenAIModule:
         """
         Run an agent with streaming enabled and automatic TaskMessage creation.
 
+        .. deprecated::
+            Use the OpenAI Agents SDK integration with Temporal instead.
+            See examples in tutorials/10_async/10_temporal/ for migration guidance.
+
         Args:
             task_id: The ID of the task to run the agent for.
             input_list: List of input data for the agent.
@@ -494,4 +509,4 @@ class OpenAIModule:
                 output_guardrails=output_guardrails,
                 max_turns=max_turns,
                 previous_response_id=previous_response_id,
-            )
+            )
\ No newline at end of file
