@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from pydantic import Field, BaseModel, validator, model_validator
 
 
@@ -45,6 +47,7 @@ class TemporalConfig(BaseModel):
         enabled: Whether this agent uses Temporal workflows
         workflow: The temporal workflow configuration
         workflows: The list of temporal workflow configurations
+        health_check_port: Port for temporal worker health check endpoint
     """
 
     enabled: bool = Field(
@@ -58,6 +61,10 @@ class TemporalConfig(BaseModel):
         default=None,
         description="List of temporal workflow configurations. Used when enabled=true.",
     )
+    health_check_port: int | None = Field(
+        default=None,
+        description="Port for temporal worker health check endpoint. Defaults to 80 if not specified.",
+    )
 
     @validator("workflows")
     def validate_workflows_not_empty(cls, v):
